"""
Script to create the figures for the paper "A decade of detailed observations (2008--2018) in steep 
bedrock permafrost at Matterhorn Hoernligrat (Zermatt, CH)"

Copyright (c) 2020, Swiss Federal Institute of Technology (ETH Zurich)
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
  list of conditions and the following disclaimer.

* Redistributions in binary form must reproduce the above copyright notice,
  this list of conditions and the following disclaimer in the documentation
  and/or other materials provided with the distribution.

* Neither the name of the copyright holder nor the names of its
  contributors may be used to endorse or promote products derived from
  this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

@date: March 31, 2020
@author: Samuel Weber
"""
# Import Libraries
import sys, inspect
import socket
import os as os
import numpy as np
import pandas as pd
import datetime as dt
import matplotlib as mpl
import matplotlib.pyplot as plt
import matplotlib.dates as mdates
import matplotlib.transforms as mtransforms

# remove matplotlib warning 
from pandas.plotting import register_matplotlib_converters
register_matplotlib_converters()


# Load functions in relative path
# pwd = os.path.dirname(os.path.abspath(os.getcwd()))
pwd = os.path.dirname(os.path.abspath(__file__))
print(pwd)
# os.chdir('..')

# try:
#     sys.path.remove('/home/webersam/Documents/gitlab/permasense/')
# except:
#     pass
# sys.path.append(pwd + '/permasense/')
# sys.path.append('/home/perma/permasense_vault/scratch/essd_zenodo_datamgr/')
# sys.path.append('~/permasense/')

current_dir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
parent_dir = os.path.dirname(current_dir)
sys.path.insert(0, parent_dir) 

# sys.path.append('/home/perma/permasense_vault/scratch/essd_zenodo_datamgr/')
from collections import OrderedDict
from permasense.GSNdata import get_GSNdata, save_data, load_data, filter_data, clean_data
from permasense.plotting import dataavailability_flags, nodata_rectangles, colorbar_hydrologicalyears

os.chdir(pwd)

# For proper plotting on server
if socket.gethostname() == 'tik43x':
    mpl.use('Agg')

ALL_FIG = True
fig_weatherstation = True
fig_rocktemperature = True
fig_displacement = True
fig_displacement_gps = True
fig_resistivity = True
fig_gps = True
fig_DRC = True
fig_dataavailability = True
#%% DEFINE PATH DATA
if os.getcwd() == '/home/perma/permasense_vault/datasets/mh_2008_2018/essd_paper/figures4paper': 
    PATH_DATA = './../../pangaea_mh_data_2008_2019/'
    PATH_FIGURES = './figures/'
elif os.getcwd() == '/home/perma/permasense_vault/scratch/essd_zenodo_datamgr/examples': 
    PATH_DATA = './../mh_data/'
    PATH_FIGURES = './figures/'
else:
    PATH_DATA = './../mh_data/'
    PATH_FIGURES = './figures/'
#PATH_DATA = './../../../datasets/mh_2008_2018/pangaea_mh_data_2008_2019/'
# Create PATH_DATA if it does not exist yet
# os.makedirs(PATH_DATA, exist_ok=True)    
os.makedirs(PATH_FIGURES, exist_ok=True)    

year_list = list(range(2008, dt.datetime.today().year + 1))
color_list = mpl.cm.tab10(np.linspace(0, 1, len(year_list))) # OR itertools.cycle(["r", "b", "g"]) with import itertools
if len(year_list) <= 10: 
    color_list = mpl.cm.tab10(range(0, len(year_list))) # OR itertools.cycle(["r", "b", "g"]) with import itertools
elif len(year_list) > 10:
    color_list = mpl.cm.tab20(range(0, len(year_list))) # OR itertools.cycle(["r", "b", "g"]) with import itertools

years = mdates.YearLocator()   # every year
biyearly =mdates.YearLocator(2)
months = mdates.MonthLocator()  # every month
yearsFmt = mdates.DateFormatter('%Y')

xpos_ylabel_square = -0.14

plt.rcParams.update({'font.size': 12})

color1 = 'black' #color = 'deepskyblue'
color2 = 'C2'#'deepskyblue' #color = 'deepskyblue'

#downsampling_freq = '1Y'
#downsampling_freq = '1W' #weekly
downsampling_freq = '1440Min' #daily


#%% MH25/MH15: air temperature and radiation
if fig_weatherstation | ALL_FIG:
    depo1 = 'MH25'
    vsensor1 = 'vaisalawxt520windpth'
    df1 = load_data(PATH_DATA + 'timeseries_derived_data_products/', depo1, vsensor1, year=year_list, file_type='csv')
    df1  = df1.groupby(pd.Grouper(freq=downsampling_freq)).aggregate(np.mean)
    
    depo2 = 'MH15'
    vsensor2 = 'radiometer__conv'
    df2 = load_data(PATH_DATA + 'timeseries_derived_data_products/', depo2, vsensor2, year=year_list, file_type='csv')
    df2  = df2.groupby(pd.Grouper(freq='1440Min')).aggregate(np.mean)
    
    depo = '{:s}_{:s}'.format(depo1,depo2)
    vsensor = '{:s}_{:s}'.format(vsensor1,vsensor2)
    df = pd.concat([df1, df2], axis=1, join='inner')
    #df['hydrological_year'] = (df.index + pd.DateOffset(months=3)).year
    
    
    fig, ax1 = plt.subplots(1,1, figsize=(25/2.54, 10/2.54), facecolor='w', edgecolor='k')
    plt.subplots_adjust(left=0.07, right=0.93, bottom=0.08, top=0.99) # left=0.125, right=0.9, bottom=0.1, top=0.9, wspace=0.2, hspace=0.2
    #fig, ax1 = plt.subplots(1,1, figsize=(12/2.54, 8/2.54), facecolor='w', edgecolor='k')
    #plt.subplots_adjust(left=0.15, right=0.85, bottom=0.08, top=0.99) # left=0.125, right=0.9, bottom=0.1, top=0.9, wspace=0.2, hspace=0.2
    

    ax1.plot(df1['temp_air [°C]'], color=color1)
    ax1.axhline(y=0, xmin=0, xmax=1, color = 'gray', linestyle='dotted', linewidth=1)

    t1, t2 = dataavailability_flags(df1['temp_air [°C]'])
    nodata_rectangles(ax1, t1, t2)
    
  
    
    ax2 = ax1.twinx()
    ax2.plot(df2['irradiance_shortwave_up [Wm^-2]'], color=color2) #, linewidth=1 #ax3.set_ylim([44,50])
    
    
    ax1.set_ylabel('Air temperature (°C)')
    ax1.set_ylim([-45, 15])
    ax1.set_yticks(range(-30,20,10))

    ax1.xaxis.set_major_locator(biyearly)
    ax1.xaxis.set_minor_locator(years)
    ax1.set_xlim([t2[0], t1[-1]])
    date_format = mdates.DateFormatter('%Y')
    ax1.xaxis.set_major_formatter(date_format)

    ax2.set_ylabel(r'Shortwave radiation in (Wm$^{-2}$)', color=color2)
    ax2.set_ylim([0, 2400])
    ax2.set_yticks(range(0,1000,200))
    for tl in ax2.get_yticklabels():
        tl.set_color(color2)
    ax2.tick_params(axis='y', colors=color2)
    ax2.spines['right'].set_color(color2)
    
    fname = 'fig_{:s}_{:s}.png'.format(vsensor, depo)
    plt.savefig(PATH_FIGURES + fname, format='png', dpi=300) #bbox_inches="tight", pad_inches=0,





#%% MH10: rock temperature
if fig_rocktemperature | ALL_FIG:
    depo = 'MH10'
    vsensor = 'temperature_rock'
    df = load_data(PATH_DATA + 'timeseries_derived_data_products/', depo, vsensor, year=year_list, file_type='csv')
    df  = df.groupby(pd.Grouper(freq=downsampling_freq)).aggregate(np.mean)
    #df.rename(columns={'temperature_nearsurface_t2 [°C]':'temperature_nearsurface [°C]'}, inplace=True)
    
    fig, ax = plt.subplots(1,1, figsize=(25/2.54, 12/2.54), facecolor='w', edgecolor='k')
    plt.subplots_adjust(left=0.07, right=0.995, bottom=0.08, top=0.99) # left=0.125, right=0.9, bottom=0.1, top=0.9, wspace=0.2, hspace=0.2
    #fig, ax = plt.subplots(1,1, figsize=(12/2.54, 8/2.54), facecolor='w', edgecolor='k')
    #plt.subplots_adjust(left=0.15, right=0.995, bottom=0.08, top=0.99) # left=0.125, right=0.9, bottom=0.1, top=0.9, wspace=0.2, hspace=0.2
#    ax.plot(df['temperature_nearsurface_t2 [°C]'], label='near surface')
    #ax.plot(df['temperature_5cm [°C]'], label='5 cm')
    ax.plot(df['temperature_10cm [°C]'], label='10 cm')
    #ax.plot(df['temperature_20cm [°C]'], label='20 cm')
    #ax.plot(df['temperature_30cm [°C]'], label='30 cm')
#    ax.plot(df['temperature_35cm [°C]'], label='35 cm')
    #ax.plot(df['temperature_50cm [°C]'], label='50 cm')
#    ax.plot(df['temperature_60cm [°C]'], label='60 cm')
    ax.plot(df['temperature_85cm [°C]'], label='85 cm')
    #ax.plot(df['temperature_100cm [°C]'], label='100 cm')
    
    t1, t2 = dataavailability_flags(df['position []'])
    nodata_rectangles(ax, t1, t2)
    
    ax.axhline(y=0, xmin=0, xmax=1, color = 'gray', linestyle='dotted', linewidth=1)
    
    counter = 0
    print(df.index.year.unique())

    for y in df.index.year.unique():
        df_y = df.loc[df.index.year == y,:]
        df_y_int = df_y.interpolate(method='linear')
        # print(df_y)
        print(np.sum(~np.isnan(df_y_int['temperature_85cm [°C]'].values)))
        # if np.sum(~np.isnan(df_y_int['temperature_85cm [°C]'].values)) > 357 * 24 :
        if np.sum(~np.isnan(df_y_int['temperature_85cm [°C]'].values)) > 357 :
            magt = np.mean(df_y_int['temperature_85cm [°C]'])
            print(magt)
            if counter == 0:
                ax.plot([dt.datetime(y,1,1), dt.datetime(y+1,1,1)], [magt, magt], color='black', label='MAGT 85cm')
                counter += 1
            else:
                ax.plot([dt.datetime(y,1,1), dt.datetime(y+1,1,1)], [magt, magt], color='black')
            
    ax.xaxis.set_major_locator(biyearly)
    ax.xaxis.set_minor_locator(years)
    ax.xaxis.set_major_formatter(date_format)
    #ax.xaxis.set_major_locator(years)
    date_format = mdates.DateFormatter('%Y')
    ax.xaxis.set_major_formatter(date_format)
    ax.set_xlim([t2[0], t1[-1]])
    ax.set_ylabel('Temperature rock (°C)')
    ax.set_ylim([-25,25])
    ax.set_yticks(range(-20,30,10))
    ax.legend(ncol=3, facecolor='white', edgecolor='black', loc='lower right', bbox_to_anchor=(1.01, -0.02), handlelength=1.4) # frameon=False, 
    
    
    fname = 'fig_{:s}_{:s}.png'.format(vsensor, depo)
    plt.savefig(PATH_FIGURES + fname, format='png', dpi=300) #bbox_inches="tight", pad_inches=0,


#%% MH10: resistivity rock
if fig_resistivity | ALL_FIG:
    depo = 'MH10'
    vsensor = 'resistivity_rock'
    df = load_data(PATH_DATA + 'timeseries_derived_data_products/', depo, vsensor, year=year_list, file_type='csv')
    #df.rename(columns={'temperature_nearsurface_t2 [°C]':'temperature_nearsurface [°C]'}, inplace=True)
    
    fig, ax = plt.subplots(1,1, figsize=(25/2.54, 12/2.54), facecolor='w', edgecolor='k')
    plt.subplots_adjust(left=0.07, right=0.995, bottom=0.07, top=0.99) # left=0.125, right=0.9, bottom=0.1, top=0.9, wspace=0.2, hspace=0.2
    #fig, ax = plt.subplots(1,1, figsize=(12/2.54, 8/2.54), facecolor='w', edgecolor='k')
    #plt.subplots_adjust(left=0.13, right=0.995, bottom=0.08, top=0.99) # left=0.125, right=0.9, bottom=0.1, top=0.9, wspace=0.2, hspace=0.2
    ax.plot(df['resistivity_85cm [Mohm]'], color=color1)
#    ax.plot(df['resistivity_35_85cm [Mohm]'])
    
    t1, t2 = dataavailability_flags(df['position []'])
    nodata_rectangles(ax, t1, t2)
    
    ax.xaxis.set_major_locator(biyearly)
    ax.xaxis.set_minor_locator(years)
    date_format = mdates.DateFormatter('%Y')
    ax.xaxis.set_major_formatter(date_format)
    ax.set_xlim([t2[0], t1[-1]])
    ax.set_ylabel(r'Resistivity at 85cm (M$\Omega$)')
    ax.set_ylim([0,20])
    ax.set_yticks(range(0,20,2))
    
    fname = 'fig_{:s}_{:s}.png'.format(vsensor, depo)
    plt.savefig(PATH_FIGURES + fname, format='png', dpi=300) #bbox_inches="tight", pad_inches=0,


#%% MH03: fracture displacement dx1 ACROSS time
    
if fig_displacement | ALL_FIG:
    depo = 'MH03'
    vsensor = 'displacement'
    df = load_data(PATH_DATA + 'timeseries_derived_data_products/', depo, vsensor, year=year_list, file_type='csv')
    
    
    fig, ax = plt.subplots(1,1, figsize=(25/2.54, 10/2.54), facecolor='w', edgecolor='k')
    plt.subplots_adjust(left=0.07, right=0.995, bottom=0.07, top=0.99) # left=0.125, right=0.9, bottom=0.1, top=0.9, wspace=0.2, hspace=0.2
    #fig, ax = plt.subplots(1,1, figsize=(12/2.54, 8/2.54), facecolor='w', edgecolor='k')
    #plt.subplots_adjust(left=0.13, right=0.995, bottom=0.07, top=0.99) # left=0.125, right=0.9, bottom=0.1, top=0.9, wspace=0.2, hspace=0.2

    ax.plot(df['displacement_dx1 [mm]'], color=color1)
    
    tbeg=dt.datetime(2010, 6, 1,  tzinfo=dt.timezone.utc)
    tend=dt.datetime(2010, 8, 15, tzinfo=dt.timezone.utc)
    ax.plot(df['displacement_dx1 [mm]'][(df.index>tbeg) & (df.index<tend)], color='C3')
    
    tbeg=dt.datetime(2015, 6, 1, tzinfo=dt.timezone.utc)
    tend=dt.datetime(2015, 9, 1, tzinfo=dt.timezone.utc)
    ax.plot(df['displacement_dx1 [mm]'][(df.index>tbeg) & (df.index<tend)], color='C3')
    
    tbeg=dt.datetime(2016, 6, 1, tzinfo=dt.timezone.utc)
    tend=dt.datetime(2019, 1, 1, tzinfo=dt.timezone.utc)
    ax.plot(df['displacement_dx1 [mm]'][(df.index>tbeg) & (df.index<tend)], color='C1')
    
    ind = ((df.index > tbeg) & (df.index < tend))
    
    t1, t2 = dataavailability_flags(df['position []'])
    nodata_rectangles(ax, t1, t2)
    
    ax.xaxis.set_major_locator(biyearly)
    ax.xaxis.set_minor_locator(years)
    date_format = mdates.DateFormatter('%Y')
    ax.xaxis.set_major_formatter(date_format)
    ax.set_xlim([t2[0], t1[-1]])
    ax.set_ylabel('Fracture displacement (mm)')
    
    fname = 'fig_{:s}_{:s}.png'.format(vsensor, depo)
    plt.savefig(PATH_FIGURES + fname, format='png', dpi=300) #bbox_inches="tight", pad_inches=0,


#%% HOGR, MH33-MH55: displacement ACROSS time
# if fig_displacement_gps | ALL_FIG:
    
#     fig, ax = plt.subplots(3,1, figsize=(25/2.54, 28/2.54), facecolor='w', edgecolor='k', sharex=True)
#     plt.subplots_adjust(left=0.1, right=0.995, bottom=0.07, top=0.99, hspace=0.1) # left=0.125, right=0.9, bottom=0.1, top=0.9, wspace=0.2, hspace=0.2
#     #fig, ax = plt.subplots(1,1, figsize=(12/2.54, 8/2.54), facecolor='w', edgecolor='k')
#     #plt.subplots_adjust(left=0.13, right=0.995, bottom=0.07, top=0.99) # left=0.125, right=0.9, bottom=0.1, top=0.9, wspace=0.2, hspace=0.2
    
#     depo_list = ['MH42', 'MH33', 'MH34', 'MH35']
#     label_list = ['HOGR', 'MH33', 'MH34', 'MH35']
#     col_list = [color1, color2, 'C3', 'C1']
#     counter=0
#     for depo in depo_list:
#         vsensor = 'gps_differential__batch__daily'
#         vsensor = 'gps_differential__rtklib__daily'
#         df = load_data(PATH_DATA + 'gnss_derived_data_products/', depo, vsensor, year=year_list, file_type='csv')
#         df = df.groupby(pd.Grouper(freq='1440Min')).aggregate(np.mean)
#         ax[0].plot((df['n [m]']-df['n [m]'][-1])*1000, color=col_list[counter], label=label_list[counter])
#         ax[1].plot((df['e [m]']-df['e [m]'][-1])*1000, color=col_list[counter], label=label_list[counter])
#         ax[2].plot((df['h [m]']-df['h [m]'][-1])*1000, color=col_list[counter], label=label_list[counter])
#         counter += 1
        
#         if depo=='MH42':
#             t1 = df.index[0]
#             t2 = df.index[-1]
    
#     ax[0].set_ylabel('Relative coordinates North (mm)')
#     ax[1].set_ylabel('Relative coordinates East (mm)')
#     ax[2].set_ylabel('Relative coordinates Altitude (mm)')

#     xpos_ylabel = -0.07
#     for i in range(3):
#         ax[i].yaxis.set_label_coords(xpos_ylabel, 0.5)
#         ax[i].xaxis.set_minor_locator(years)
#         ax[i].xaxis.set_major_locator(biyearly)
#         ax[i].axhline(y=0, xmin=0, xmax=1, color = 'darkgray', linewidth=2)
#         ax[i].legend(loc=1, ncol=2, frameon=False)
    
#     date_format = mdates.DateFormatter('')
#     ax[0].xaxis.set_major_formatter(date_format)
#     date_format = mdates.DateFormatter('%Y')
#     ax[2].xaxis.set_major_formatter(date_format)
    
#     ax[0].set_ylim([-100, 300])
#     ax[1].set_ylim([-200, 120])
#     ax[2].set_ylim([-100, 200])
#     ax[2].set_xlim([t1,t2])
    
    
    
#     fname = 'fig_displacement_gps.png'.format(vsensor, depo)
#     plt.savefig(PATH_FIGURES + fname, format='png', dpi=300) #bbox_inches="tight", pad_inches=0,

#%% HOGR, MH33-MH55: displacement ACROSS time
if fig_displacement_gps | ALL_FIG:
    
    fig, ax = plt.subplots(3,1, figsize=(25/2.54, 25/2.54), facecolor='w', edgecolor='k', sharex=True)
    plt.subplots_adjust(left=0.09, right=0.995, bottom=0.05, top=0.99, hspace=0.05) # left=0.125, right=0.9, bottom=0.1, top=0.9, wspace=0.2, hspace=0.2
    #fig, ax = plt.subplots(1,1, figsize=(12/2.54, 8/2.54), facecolor='w', edgecolor='k')
    #plt.subplots_adjust(left=0.13, right=0.995, bottom=0.07, top=0.99) # left=0.125, right=0.9, bottom=0.1, top=0.9, wspace=0.2, hspace=0.2
    
    
    depo = 'MH42'
    vsensor = 'gps_differential__rtklib__daily'
    #vsensor = 'gps_differential__batch__daily'
    df = load_data(PATH_DATA + 'gnss_derived_data_products/', depo, vsensor, year=year_list, file_type='csv')
    df  = df.groupby(pd.Grouper(freq='1440Min')).aggregate(np.mean)        
    ax[0].plot((df['e [m]']-df['e [m]'][-1])*1000, color=color1, label='HOGR')
    ax[1].plot((df['n [m]']-df['n [m]'][-1])*1000, color=color1, label='HOGR')
    ax[2].plot((df['h [m]']-df['h [m]'][-1])*1000, color=color1, label='HOGR')
    t1 = df.index[1]
    t2 = df.index[-2]
    trng_reindex = pd.date_range(t1, t2, freq='24h')#, utc=True) # dt.date.today()-dt.timedelta(30)
    df_HOGR = df.reindex(trng_reindex)
    
    
    depo_list = ['MH33', 'MH34', 'MH35']
    label_list = ['MH33', 'MH34', 'MH35']
    col_list = [color2, 'C3', 'C1']
    counter=0
    for depo in depo_list:
        vsensor = 'gps_differential__rtklib__daily'
        #vsensor = 'gps_differential__batch__daily'
        df = load_data(PATH_DATA + 'gnss_derived_data_products/', depo, vsensor, year=year_list, file_type='csv')
        df = df.groupby(pd.Grouper(freq='1440Min')).aggregate(np.mean)
        df = df.reindex(trng_reindex)
        
        df_corrHOGR = df_HOGR + df
        ax[0].plot((df_corrHOGR['e [m]']-df_corrHOGR.ffill()['e [m]'][-1])*1000, color=col_list[counter], label=label_list[counter])
        ax[1].plot((df_corrHOGR['n [m]']-df_corrHOGR.ffill()['n [m]'][-1])*1000, color=col_list[counter], label=label_list[counter])
        ax[2].plot((df_corrHOGR['h [m]']-df_corrHOGR.ffill()['h [m]'][-1])*1000, color=col_list[counter], label=label_list[counter])
        counter += 1
    
    ax[0].set_ylabel('Relative coordinates East (mm)')
    ax[1].set_ylabel('Relative coordinates North (mm)')
    ax[2].set_ylabel('Relative coordinates Altitude (mm)')

    xpos_ylabel = -0.07
    for i in range(3):
        ax[i].yaxis.set_label_coords(xpos_ylabel, 0.5)
        ax[i].xaxis.set_minor_locator(years)
        ax[i].xaxis.set_major_locator(biyearly)
        ax[i].axhline(y=0, xmin=0, xmax=1, color = 'gray', linestyle='dotted', linewidth=1)
        ax[i].legend(loc=2, ncol=4, frameon=False)
    
    date_format = mdates.DateFormatter('')
    ax[0].xaxis.set_major_formatter(date_format)
    date_format = mdates.DateFormatter('%Y')
    ax[2].xaxis.set_major_formatter(date_format)
    
    ax[0].set_ylim([-400, 100])
    ax[1].set_ylim([-50, 450])
    ax[2].set_ylim([-100, 250])
    ax[2].set_xlim([t1,t2])
    
    fname = 'fig_displacement_gps.png'.format(vsensor, depo)
    plt.savefig(PATH_FIGURES + fname, format='png', dpi=300) #bbox_inches="tight", pad_inches=0,

#%% MH34: gps (displacement and inclinometer)
if fig_gps | ALL_FIG:
    depo1 = 'MH34'
    vsensor1 = 'gps_differential__rtklib__daily'
    df1 = load_data(PATH_DATA + 'gnss_derived_data_products/', depo1, vsensor1, year=year_list, file_type='csv')
    df1  = df1.groupby(pd.Grouper(freq='1440Min')).aggregate(np.mean)
    df1['3d [mm]'] = np.sqrt((df1['n [m]']-df1['n [m]'][0])**2 + (df1['e [m]']-df1['e [m]'][0])**2 + (df1['h [m]']-df1['h [m]'][0])**2) * 1000
    
    depo2 = 'MH34'
    vsensor2 = 'gps_inclinometer'
    df2 = load_data(PATH_DATA + 'timeseries_derived_data_products/', depo2, vsensor2, year=year_list, file_type='csv')
    df2  = df2.groupby(pd.Grouper(freq='1440Min')).aggregate(np.mean)
    
    depo = '{:s}_{:s}'.format(depo1,depo2)
    vsensor = '{:s}_{:s}'.format(vsensor1,vsensor2)
    df = pd.concat([df1, df2], axis=1, join='inner')
    #df['hydrological_year'] = (df.index + pd.DateOffset(months=3)).year
    
    
    #fig, ax1 = plt.subplots(1,1, figsize=(25/2.54, 10/2.54), facecolor='w', edgecolor='k')
    #plt.subplots_adjust(left=0.07, right=0.93, bottom=0.08, top=0.99) # left=0.125, right=0.9, bottom=0.1, top=0.9, wspace=0.2, hspace=0.2
    fig, ax1 = plt.subplots(1,1, figsize=(12/2.54, 8/2.54), facecolor='w', edgecolor='k')
    plt.subplots_adjust(left=0.14, right=0.84, bottom=0.09, top=0.99) # left=0.125, right=0.9, bottom=0.1, top=0.9, wspace=0.2, hspace=0.2
    
    ax1.plot(df1['3d [mm]'], color=color2)
    
    # ax1.set_ylabel('Inclination (°)', color=color2)
    # ax1.set_ylim([-2,2])
    # ax1.set_yticks(np.arange(-2,2,0.4))
    for tl in ax1.get_yticklabels():
        tl.set_color(color2)
    ax1.tick_params(axis='y', colors=color2)
    ax1.spines['left'].set_color(color2)
    
    t1, t2 = dataavailability_flags(df1['position []'])
    nodata_rectangles(ax1, t1, t2)
    
   
    ax2 = ax1.twinx()
    ax2.plot(df2['inclinometer_west [°]'] - df2['inclinometer_west [°]'][df2['inclinometer_west [°]'].notna()][0], color=color1, zorder=2) #, linewidth=1 #ax3.set_ylim([44,50])
    
    
    ax1.set_ylabel('Relative 3D coordinates (mm)', color=color2)
    ax1.set_ylim([-25,375])
    ax1.set_yticks(range(0,400,50))
    
    ax1.xaxis.set_major_locator(years)
    date_format = mdates.DateFormatter('%Y')
    ax1.xaxis.set_major_formatter(date_format)
    ax1.set_xlim(df1['3d [mm]'].index[0], df1['3d [mm]'].index[-1])

    
    ax2.set_ylabel('Inclination (°)', color=color1)
    ax2.set_ylim([-0.25,2.25])
    ax2.set_yticks(np.arange(0,2.5,0.5))
    for tl in ax2.get_yticklabels():
        tl.set_color(color1)
    ax2.tick_params(axis='y', colors=color1)
    ax2.spines['right'].set_color(color1)
        
    fname = 'fig_{:s}_{:s}.png'.format(vsensor, depo)
    plt.savefig(PATH_FIGURES + fname, format='png', dpi=300) #bbox_inches="tight", pad_inches=0,
    
    
    
    ## MH10/MH08: temperature rock (85cm) VS displacement (dx2)
    depo1 = 'MH10'
    vsensor1 = 'temperature_rock'
    df1 = load_data(PATH_DATA + 'timeseries_derived_data_products/', depo1, vsensor1, year=year_list, file_type='csv')
    df1 = df1[~np.isnan(df1['temperature_60cm [°C]'])]
    df1  = df1.groupby(pd.Grouper(freq='1440Min')).aggregate(np.mean)
    
    depo2 = 'MH34'
    #vsensor2 = 'gps_inclinometer'
    vsensor2 = 'gps_differential__rtklib__daily'
    #df2 = load_data(PATH_DATA + 'timeseries_derived_data_products/', depo2, vsensor2, year=year_list, file_type='csv')
    df2 = load_data(PATH_DATA + 'gnss_derived_data_products/', depo2, vsensor2, year=year_list, file_type='csv')
    df2['3d [mm]'] = np.sqrt((df2['n [m]']-df2['n [m]'][0])**2 + (df2['e [m]']-df2['e [m]'][0])**2 + (df2['h [m]']-df2['h [m]'][0])**2) * 1000
    df2  = df2.groupby(pd.Grouper(freq='1440Min')).aggregate(np.mean)
    
    depo = '{:s}_{:s}'.format(depo1,depo2)
    vsensor = '{:s}_{:s}'.format(vsensor1,vsensor2)
    df = pd.concat([df1, df2], axis=1, join='inner')
    df['hydrological_year'] = (df.index + pd.DateOffset(months=3)).year
    
    
    fig, ax = plt.subplots(1,1, figsize=(12/2.54, 10/2.54), facecolor='w', edgecolor='k')
    plt.subplots_adjust(left=0.14, right=0.88, bottom=0.13, top=0.99) # left=0.125, right=0.9, bottom=0.1, top=0.9, wspace=0.2, hspace=0.2
    
    color_list_tmp = color_list.copy()
    year_list_tmp = year_list.copy()
    for i, y in enumerate(year_list):
        if len(df[df['hydrological_year'] == y]) == 0:
            color_list_tmp[i] = np.zeros(4)
            year_list_tmp[i] = ''
    
    for i, y in enumerate(year_list):#enumerate(np.unique(df['hydrological_year'])):
        df_y = df[df['hydrological_year'] == y]
        col_y = color_list[i] #y - year_list[0]
        try:
            #ax.plot(df_y['temperature_85cm [°C]'], df_y['inclinometer_x [°]'] - df_y['inclinometer_x [°]'][0],'.',color=col_y)
            ax.plot(df_y['temperature_85cm [°C]'], df_y['3d [mm]'],'.',color=col_y)
        except:
            pass
    
    ax.set_xlabel('Temperature rock (°C)')
    ax.set_ylabel('Relative 3D coordinates (mm)')
    ax.yaxis.set_label_coords(xpos_ylabel_square, 0.5)
    ax.set_xlim([-12,12])
    ax.set_xticks(range(-12,16,4))
    
    colorbar_hydrologicalyears(color_list_tmp,year_list)
    
    fname = 'fig_{:s}_{:s}.png'.format(vsensor, depo)
    plt.savefig(PATH_FIGURES + fname, format='png', dpi=300) #bbox_inches="tight", pad_inches=0,
    


#%%
if fig_DRC | ALL_FIG:
    ## MH10/MH08: temperature rock (85cm) VS displacement (dx2)
    depo1 = 'MH10'
    vsensor1 = 'temperature_rock'
    df1 = load_data(PATH_DATA + 'timeseries_derived_data_products/', depo1, vsensor1, year=year_list, file_type='csv')
    df1 = df1[~np.isnan(df1['temperature_60cm [°C]'])]
    df1  = df1.groupby(pd.Grouper(freq='1440Min')).aggregate(np.mean)
    
    depo2 = 'MH08'
    vsensor2 = 'displacement'
    df2 = load_data(PATH_DATA + 'timeseries_derived_data_products/', depo2, vsensor2, year=year_list, file_type='csv')
    df2 = df2[~np.isnan(df2['displacement_dx1 [mm]'])]
    df2  = df2.groupby(pd.Grouper(freq='1440Min')).aggregate(np.mean)
    
    depo = '{:s}_{:s}'.format(depo1,depo2)
    vsensor = '{:s}_{:s}'.format(vsensor1,vsensor2)
    df = pd.concat([df1, df2], axis=1, join='inner')
    df['hydrological_year'] = (df.index + pd.DateOffset(months=3)).year
    
    
    fig, ax = plt.subplots(1,1, figsize=(12/2.54, 10/2.54), facecolor='w', edgecolor='k')
    plt.subplots_adjust(left=0.14, right=0.88, bottom=0.13, top=0.99) # left=0.125, right=0.9, bottom=0.1, top=0.9, wspace=0.2, hspace=0.2
    
    color_list_tmp = color_list.copy()
    year_list_tmp = year_list.copy()
    for i, y in enumerate(year_list):
        if len(df[df['hydrological_year'] == y]) == 0:
            color_list_tmp[i] = np.zeros(4)
            year_list_tmp[i] = ''
    
    for i, y in enumerate(year_list):#enumerate(np.unique(df['hydrological_year'])):
        df_y = df[df['hydrological_year'] == y]
        col_y = color_list[i] #y - year_list[0]
        ax.plot(df_y['temperature_85cm [°C]'], df_y['displacement_dx2 [mm]'],'.',color=col_y)
    
    ax.set_xlabel('Temperature rock (°C)')
    ax.set_ylabel('Fracture displacement (mm)')
    ax.yaxis.set_label_coords(xpos_ylabel_square, 0.5)
    ax.set_xlim([-12,12])
    ax.set_xticks(range(-12,16,4))
    
    colorbar_hydrologicalyears(color_list_tmp,year_list)
    
    fname = 'fig_{:s}_{:s}.png'.format(vsensor, depo)
    plt.savefig(PATH_FIGURES + fname, format='png', dpi=300) #bbox_inches="tight", pad_inches=0,
    
    
    
    ## MH10/MH10: temperature rock VS resistivity
    depo = 'MH10'
    vsensor1 = 'temperature_rock'
    df1 = load_data(PATH_DATA + 'timeseries_derived_data_products/', depo, vsensor1, year=year_list, file_type='csv')
    df1  = df1.groupby(pd.Grouper(freq='1440Min')).aggregate(np.mean)
    
    vsensor2 = 'resistivity_rock'
    df2 = load_data(PATH_DATA + 'timeseries_derived_data_products/', depo, vsensor2, year=year_list, file_type='csv')
    df2  = df2.groupby(pd.Grouper(freq='1440Min')).aggregate(np.mean)
    
    vsensor = '{:s}_{:s}'.format(vsensor1,vsensor2)
    df = pd.concat([df1, df2], axis=1, join='inner')
    df['hydrological_year'] = (df.index + pd.DateOffset(months=3)).year
    
    
    fig, ax = plt.subplots(1,1, figsize=(12/2.54, 10/2.54), facecolor='w', edgecolor='k')
    plt.subplots_adjust(left=0.14, right=0.88, bottom=0.13, top=0.99) # left=0.125, right=0.9, bottom=0.1, top=0.9, wspace=0.2, hspace=0.2
    
    color_list_tmp = color_list.copy()
    year_list_tmp = year_list.copy()
    for i, y in enumerate(year_list):
        if len(df[df['hydrological_year'] == y]) == 0:
            color_list_tmp[i] = np.zeros(4)
            year_list_tmp[i] = ''
            
    for i, y in enumerate(year_list):
        df_y = df[df['hydrological_year'] == y]
        col_y = color_list[i]
        ax.plot(df_y['temperature_85cm [°C]'], df_y['resistivity_85cm [Mohm]'],'.',color=col_y)
    
    ax.set_xlabel('Temperature rock (°C)'.format(depo))
    ax.set_ylabel(r'Resistivity rock (M$\Omega)$')
    #xpos_ylabel_square = -0.15
    ax.yaxis.set_label_coords(xpos_ylabel_square, 0.5)
    ax.set_xlim([-12,12])
    ax.set_xticks(range(-12,16,4))
    ax.set_ylim([0,19])
    ax.set_yticks(range(0,20,2))
    colorbar_hydrologicalyears(color_list_tmp,year_list)
    
    fname = 'fig_{:s}_{:s}.png'.format(vsensor, depo)
    plt.savefig(PATH_FIGURES + fname, format='png', dpi=300) #bbox_inches="tight", pad_inches=0,
    
    
    
    ## MH10/MH42: temperature rock (85cm) vs relative position(3d)
    depo1 = 'MH10'
    vsensor1 = 'temperature_rock'
    df1 = load_data(PATH_DATA + 'timeseries_derived_data_products/', depo1, vsensor1, year=year_list, file_type='csv')
    df1  = df1 .groupby(pd.Grouper(freq='1440Min')).aggregate(np.mean)
    
    depo2 = 'MH42'
    vsensor2 = 'gps_differential__rtklib__daily'
    df2 = load_data(PATH_DATA + 'gnss_derived_data_products/', depo2, vsensor2, year=year_list, file_type='csv')
    df2['3d [m]'] = np.sqrt((df2['n [m]']-df2['n [m]'][0])**2 + (df2['e [m]']-df2['e [m]'][0])**2 + (df2['h [m]']-df2['h [m]'][0])**2)
    df2  = df2 .groupby(pd.Grouper(freq='1440Min')).aggregate(np.mean)
    
  
    
    depo = '{:s}_{:s}'.format(depo1,depo2)
    vsensor = '{:s}_{:s}'.format(vsensor1,vsensor2)
    df = pd.concat([df1, df2], axis=1, join='inner')
    df['hydrological_year'] = (df.index + pd.DateOffset(months=3)).year
    
    
    fig, ax = plt.subplots(1,1, figsize=(12/2.54, 10/2.54), facecolor='w', edgecolor='k')
    plt.subplots_adjust(left=0.14, right=0.88, bottom=0.13, top=0.99) # left=0.125, right=0.9, bottom=0.1, top=0.9, wspace=0.2, hspace=0.2
    
    color_list_tmp = color_list.copy()
    year_list_tmp = year_list.copy()
    for i, y in enumerate(year_list):
        if len(df[df['hydrological_year'] == y]) == 0:
            color_list_tmp[i] = np.zeros(4)
            year_list_tmp[i] = ''

    for i, y in enumerate(year_list):
        df_y = df[df['hydrological_year'] == y]
        col_y = color_list[i]
        ax.plot(df_y['temperature_85cm [°C]'], df_y['3d [m]']*1000,'.', color=col_y)
    
    ax.set_xlabel('Temperature rock (°C)'.format(depo))
    ax.set_ylabel('Relative 3D coordinates (mm)'.format(depo))
    ax.yaxis.set_label_coords(xpos_ylabel_square, 0.5)
    ax.set_xlim([-12,12])
    ax.set_xticks(range(-12,16,4))
    ax.set_ylim([-25,225])
    ax.set_yticks(range(0,250,25))
    
    colorbar_hydrologicalyears(color_list_tmp,year_list)
    
    fname = 'fig_{:s}_{:s}.png'.format(vsensor, depo)
    plt.savefig(PATH_FIGURES + fname, format='png', dpi=300) #bbox_inches="tight", pad_inches=0,



#%%
if fig_dataavailability | ALL_FIG:
    DEPO_VS = {
            'MH01': {'displacement', 'temperature_fracture', 'temperature_rock'},  #ok
            'MH02': {'displacement', 'temperature_fracture', 'temperature_rock'},  #ok
            'MH03': {'displacement', 'temperature_fracture', 'temperature_rock'},  #ok
            'MH04': {'displacement', 'temperature_fracture', 'temperature_rock'},  #ok
            'MH05': {'temperature_fracture', 'resistivity_fracture'},              #ok but resistivity
            'MH06': {'displacement', 'temperature_rock'},                          #ok
            'MH07': {'temperature_fracture', 'resistivity_fracture'},              #ok but resistivity
            'MH08': {'displacement', 'temperature_rock'},                          #ok
            'MH09': {'displacement', 'temperature_fracture'},                      #ok
            'MH10': {'temperature_rock', 'resistivity_rock'},                      #ok but resistivity
            'MH11': {'temperature_rock', 'resistivity_rock'},                      #ok but resistivity
            'MH12': {'temperature_rock', 'resistivity_rock'},                      #ok but resistivity
            'MH18': {'displacement'},                                              #ok
            'MH20': {'displacement'},                                              #ok
            'MH21': {'displacement'},                                              #ok
            'MH22': {'displacement'},                                              #ok
            'MH27': {'temperature_rock'},                                          #ok
            'MH30': {'temperature_rock'},                                          #ok
            'MH46': {'temperature_rock'},                                          #ok
            'MH47': {'temperature_rock'},                                          #ok
    
            #'MH13': {'waterpressure'},                                            #?
            'MH15': {'radiometer__conv'},                                          #ok
            'MH25': {'vaisalawxt520windpth','vaisalawxt520prec'},                  #ok
    
            'MH33': {'gps_differential__batch__daily', 'gps_differential__rtklib__daily', 'gps_inclinometer'},        #ok
            'MH34': {'gps_differential__batch__daily', 'gps_differential__rtklib__daily', 'gps_inclinometer'},        #ok
            'MH35': {'gps_differential__batch__daily', 'gps_differential__rtklib__daily', 'gps_inclinometer'},        #ok
            'MH40': {'gps_differential__batch__daily', 'gps_differential__rtklib__daily'},                            #ok
            'MH42': {'gps_differential__batch__daily', 'gps_differential__rtklib__daily'},                            #ok
            }
    
    DEPO_VS_SORT = sorted(DEPO_VS.items(), key=lambda x: x[0])
    
    
    no_subplots = 0
    for depo in DEPO_VS_SORT:
        for vsensor in list(depo[1]):
            no_subplots += 1
    
    print(no_subplots)

    fig, ax = plt.subplots(no_subplots,1, figsize=(25/2.54, 28/2.54), facecolor='w', edgecolor='k', sharex=True, sharey=True)
    plt.subplots_adjust(left=0.26, right=0.97, bottom=0.03, top=0.99, hspace=0) # left=0.125, right=0.9, bottom=0.1, top=0.9, wspace=0.2, hspace=0.2
        
    xpos_ylabel = -0.36
        
    i=0
    for depo_vs in DEPO_VS_SORT:
    #    print(depo_vs)
        depo = depo_vs[0]
        if depo[0:2] == 'MH':
            deployment = 'matterhorn'
        position = int(depo[2:4])
        
        
        # Loop through values for a given key of dictionary DEPO_VS
        for vsensor in list(DEPO_VS[depo]):
            
            df = pd.DataFrame()
            if df.empty:
                try:
                    df = load_data(PATH_DATA + 'timeseries_derived_data_products/', depo, vsensor, year=year_list, file_type='csv')
                except:
                    pass
            if df.empty:
                try:
                    df = load_data(PATH_DATA + 'gnss_derived_data_products/', depo, vsensor, year=year_list, file_type='csv')
                except:
                    pass
            print(ax)
            print(i)
            ax[i].set_facecolor('darkgreen')
            try:
                t1, t2 = dataavailability_flags(df['position []'], daily=True)
            except:
                t1 = [pd.DataFrame([1], index=[pd.datetime(1970,1,1,1)]).index[0]]
                t2 = [pd.DataFrame([1], index=[pd.datetime(2050,1,1,1)]).index[0]]
                pass
                
            nodata_rectangles(ax[i], t1, t2, facecolor='white', alpha=1)
            
            if vsensor.startswith('gps_differential'):
                ax[i].set_ylabel('{:s} {:s}__{:s}'.format(depo, vsensor.split('__')[0], vsensor.split('__')[1]), rotation=0, ha='left')
            else:
                ax[i].set_ylabel('{:s} {:s}'.format(depo, vsensor.split('__')[0]), rotation=0, ha='left')
            
            ax[i].yaxis.set_label_coords(xpos_ylabel, 0.1)
            ax[i].grid()
            i += 1
            
    print(i)
    #for i in range(no_subplots):
    #    ax[i].yaxis.set_label_coords(xpos_ylabel, 0.05)
    #    ax[i].grid()
            
    #ax[0].set_xlim([dt.datetime(2008,9,1), dt.datetime(dt.datetime.today().year,1,1)])
    ax[0].set_xlim([dt.datetime(2008,9,1), dt.datetime(dt.datetime.today().year+1,1,1)])
    ax[0].set_yticks([])
    
    fname = 'fig_data_availability.png'
    plt.savefig(PATH_FIGURES + fname, format='png', dpi=300) #bbox_inches="tight", pad_inches=0,

#%%

## MH10/MH42: temperature rock (85cm) vs relative position(3d)
depo1 = 'MH10'
vsensor1 = 'temperature_rock'
df1 = load_data(PATH_DATA + 'timeseries_derived_data_products/', depo1, vsensor1, year=year_list, file_type='csv')
df1  = df1 .groupby(pd.Grouper(freq='1440Min')).aggregate(np.mean)

depo2 = 'MH42'
vsensor2 = 'gps_differential__rtklib__daily'
df2 = load_data(PATH_DATA + 'gnss_derived_data_products/', depo2, vsensor2, year=year_list, file_type='csv')
df2['3d [m]'] = np.sqrt((df2['n [m]']-df2['n [m]'][0])**2 + (df2['e [m]']-df2['e [m]'][0])**2 + (df2['h [m]']-df2['h [m]'][0])**2)
df2  = df2 .groupby(pd.Grouper(freq='1440Min')).aggregate(np.mean)

depo = '{:s}_{:s}'.format(depo1,depo2)
vsensor = '{:s}_{:s}'.format(vsensor1,vsensor2)
df = pd.concat([df1, df2], axis=1, join='inner')
df['hydrological_year'] = (df.index + pd.DateOffset(months=3)).year


fig, ax = plt.subplots(3,1, figsize=(12/2.54, 34/2.54), facecolor='w', edgecolor='k')
plt.subplots_adjust(left=0.14, right=0.88, bottom=0.05, top=0.99,hspace=0.1) # left=0.125, right=0.9, bottom=0.1, top=0.9, wspace=0.2, hspace=0.2

color_list_tmp = color_list.copy()
year_list_tmp = year_list.copy()
for i, y in enumerate(year_list):
    if len(df[df['hydrological_year'] == y]) == 0:
        color_list_tmp[i] = np.zeros(4)
        year_list_tmp[i] = ''

for i, y in enumerate(year_list):
    df_y = df[df['hydrological_year'] == y]
    col_y = color_list[i]
    try:
        ax[0].plot(df_y['temperature_85cm [°C]'], (df_y['n [m]'] - df['n [m]'][0])*1000,'.', color=col_y)
        ax[1].plot(df_y['temperature_85cm [°C]'], (df_y['e [m]'] - df['e [m]'][0])*1000,'.', color=col_y)
        ax[2].plot(df_y['temperature_85cm [°C]'], (df_y['h [m]'] - df['h [m]'][0])*1000,'.', color=col_y)
    except:
        pass
#
ax[2].set_xlabel('Temperature rock (°C)'.format(depo))
ax[2].set_xlim([-12,12])
ax[2].set_xticks(range(-12,16,4))
ax[0].set_ylabel('Relative N-S change (mm)'.format(depo))
ax[1].set_ylabel('Relative E-W change (mm)'.format(depo))
ax[2].set_ylabel('Relative elevation change (mm)'.format(depo))
#ax.yaxis.set_label_coords(xpos_ylabel_square, 0.5)



#ax[0].set_ylim([-25,25])
#ax.set_yticks(range(0,210,30))
#
xpos_ylabel = -0.14
for i in range(3):
    ax[i].yaxis.set_label_coords(xpos_ylabel, 0.5)
    plt.sca(ax[i])
    colorbar_hydrologicalyears(color_list_tmp,year_list)
#
fname = 'fig_{:s}_{:s}_channelwise.png'.format(vsensor, depo)
plt.savefig(PATH_FIGURES + fname, format='png', dpi=300) #bbox_inches="tight", pad_inches=0,




#%%
if 0:
    #%% MH34: 
    depo = 'MH33'
    vsensor = 'gps_inclinometer'
    df = load_data(PATH_DATA + 'timeseries_derived_data_products/', depo, vsensor, year=year_list, file_type='csv')
    
    fig, ax = plt.subplots(1,1, figsize=(13/2.54, 13/2.54), facecolor='w', edgecolor='k')
    ax.plot(df['inclinometer_x [°]'],'.')
    ax.plot(df['inclinometer_y [°]'],'.')
    fig, ax = plt.subplots(1,1, figsize=(13/2.54, 13/2.54), facecolor='w', edgecolor='k')
    ax.plot(df['inclinometer_x [°]'], df['inclinometer_y [°]'],'.')
    ax.set_xlabel('inclinometer_x (°)')
    ax.set_ylabel('inclinometer_y  (°)')
    ax.set_xlim([-16,4])
    ax.set_xticks(range(-16,8,4))
    
    #fname = 'fig_{:s}_{:s}.pdf'.format(vsensor, depo)
    #plt.savefig(PATH_FIGURES + fname , bbox_inches="tight", pad_inches=0, format='pdf')
    
    #%% MH34: 
    depo = 'MH42'
    vsensor = 'gps_differential__rtklib__daily'
    df = load_data(PATH_DATA + 'gnss_derived_data_products/', depo, vsensor, year=year_list, file_type='csv')
    
    fig, ax = plt.subplots(1,1, figsize=(13/2.54, 13/2.54), facecolor='w', edgecolor='k')
    ax.plot(df['e [m]'], df['n [m]'],'.')
    #ax.set_xlabel('Temperature (°C)')
    #ax.set_ylabel(r'Resistivity  (M$\Omega)$')
    #ax.set_xlim([-16,4])
    #ax.set_xticks(range(-16,8,4))
    
    #fname = 'fig_{:s}_{:s}.pdf'.format(vsensor, depo)
    #plt.savefig(PATH_FIGURES + fname , bbox_inches="tight", pad_inches=0, format='pdf')
    
    #%% MH42: 
    depo = 'MH42'
    vsensor1 = 'gps_differential__rtklib__daily'
    df = load_data(PATH_DATA + 'gnss_derived_data_products/', depo, vsensor1, year=year_list, file_type='csv')
    df['3d [m]'] = np.sqrt((df['n [m]']-df['n [m]'][0])**2 + (df['e [m]']-df['e [m]'][0])**2 + (df['h [m]']-df['h [m]'][0])**2)
    df  = df .groupby(pd.Grouper(freq='1440Min')).aggregate(np.mean)
    
    depo = 'MH10'
    vsensor2 = 'temperature_rock'
    df1 = load_data(PATH_DATA + 'timeseries_derived_data_products/', depo, vsensor2, year=year_list, file_type='csv')
    df1  = df1 .groupby(pd.Grouper(freq='1440Min')).aggregate(np.mean)
    
    vsensor = '{:s}_{:s}'.format(vsensor1,vsensor2)
    df2 = pd.concat([df, df1], axis=1, join='inner')
    df2['hydrological_year'] = (df.index + pd.DateOffset(months=3)).year
    
    #fig, ax = plt.subplots(1,1, figsize=(26/2.54, 13/2.54), facecolor='w', edgecolor='k')
    #ax.plot(df['3d [m]'])
    
    fig, ax = plt.subplots(1,1, figsize=(7/2.54, 7/2.54), facecolor='w', edgecolor='k')
    #fig, ax = plt.subplots(1,1, figsize=(13/2.54, 13/2.54), facecolor='w', edgecolor='k')
    for y in np.unique(df2['hydrological_year']):
        df_y = df2[df2['hydrological_year'] == y]
        ax.plot(df_y['temperature_85cm [°C]'], df_y['3d [m]']*1000,'.')
    ax.set_xlabel('Temperature rock (°C)')
    ax.set_ylabel('Relative 3D coordinates (mm)')
    ax.set_xlim([-12,12])
    ax.set_xticks(range(-10,15,5))
    ax.set_ylim([-10,250])
    ax.set_yticks(range(0,250,50))
    
    fname = 'fig_{:s}_{:s}.pdf'.format(vsensor, depo)
    plt.savefig(PATH_FIGURES + fname , bbox_inches="tight", pad_inches=0, format='pdf')
    
    
    #%%
    
    
    #%% MH25: weather station
    depo = 'MH25'
    vsensor = 'vaisalawxt520windpth'
    df = load_data(PATH_DATA + 'timeseries_derived_data_products/', depo, vsensor, year=year_list, file_type='csv')
    
    fig, ax = plt.subplots(1,1, figsize=(26/2.54, 13/2.54), facecolor='w', edgecolor='k')
    ax.plot(df['temp_air [°C]'])
    
    
    t1, t2 = dataavailability_flags(df['position []'])
    nodata_rectangles(ax, t1, t2)
    
    #import matplotlib.transforms as mtransforms
    #dataavailability = np.isnan(df['temp_air [°C]'])
    #flags = np.convolve(1 * dataavailability,[-1,1])[1:]
    #t1 = dataavailability.index[flags==1]
    #t2 = dataavailability.index[flags==-1]
    #trans = mtransforms.blended_transform_factory(ax.transData, ax.transAxes)
    #for i in range(np.min([len(t1),len(t2)])):
    #    ax.fill_between([t1[i],t2[i]],0,1,facecolor='gray', alpha=0.5, transform=trans)
    
    ax.xaxis.set_major_locator(years)
    ax.set_xlim([t2[0], t1[-1]])
    date_format = mdates.DateFormatter('%Y')
    ax.xaxis.set_major_formatter(date_format)

    ax.set_ylabel('Air temperature (°C)')
    ax.set_ylim([-30,20])
    #ax.legend(ncol=5, facecolor='white', edgecolor='black') # frameon=False, 
    
    fname = 'fig_{:s}_{:s}.pdf'.format(vsensor, depo)
    plt.savefig(PATH_FIGURES + fname , bbox_inches="tight", pad_inches=0, format='pdf')
    
    
    #%%
    #year_list = list(range(2008,2019))
    #    
    #depo = 'MH11'
    #vsensor = 'temperature_rock'
    #
    #df = load_data(PATH_DATA + 'timeseries_derived_data_products/', depo, vsensor, year=year_list, file_type='csv')
    #
    #plt.figure(figsize=(24/2.54, 18/2.54), facecolor='w', edgecolor='k')
    #plt.plot(df['temperature_10cm [°C]'])
    #plt.plot(df['temperature_35cm [°C]'])
    #plt.plot(df['temperature_60cm [°C]'])
    #plt.plot(df['temperature_85cm [°C]'])
    
    
    _fmt = mdates.DateFormatter('%Y-%m-%d')
    _fmt.format_data_short = lambda pos: mdates.num2date(pos).strftime("%Y-%m-%d; %H:%M:%S")
    ax.xaxis.set_major_formatter(_fmt)
