"""
Script to create the figures for the paper "XXXXXXXXXXXXXX"

Copyright (c) 2020, Swiss Federal Institute of Technology (ETH Zurich)
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
  list of conditions and the following disclaimer.

* Redistributions in binary form must reproduce the above copyright notice,
  this list of conditions and the following disclaimer in the documentation
  and/or other materials provided with the distribution.

* Neither the name of the copyright holder nor the names of its
  contributors may be used to endorse or promote products derived from
  this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

@date: March 31, 2020
@author: Samuel Weber, Jan Beutel
"""
# Import Libraries
import sys, inspect
import socket
import os as os
import numpy as np
import pandas as pd
import datetime as dt
import matplotlib as mpl
import matplotlib.pyplot as plt
import matplotlib.dates as mdates
import matplotlib.transforms as mtransforms

# remove matplotlib warning 
from pandas.plotting import register_matplotlib_converters
register_matplotlib_converters()

# Load functions in relative path
# pwd = os.path.dirname(os.path.abspath(os.getcwd()))
pwd = os.path.dirname(os.path.abspath(__file__))
print(pwd)
# os.chdir('..')

# try:
#     sys.path.remove('/home/webersam/Documents/gitlab/permasense/')
# except:
#     pass
# sys.path.append(pwd + '/permasense/')
# sys.path.append('/home/perma/permasense_vault/scratch/essd_zenodo_datamgr/')
# sys.path.append('~/permasense/')

current_dir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
parent_dir = os.path.dirname(current_dir)
sys.path.insert(0, parent_dir) 

# sys.path.append('/home/perma/permasense_vault/scratch/essd_zenodo_datamgr/')
from collections import OrderedDict
from permasense.GSNdata import get_GSNdata, save_data, load_data, filter_data, clean_data
from permasense.plotting import dataavailability_flags, nodata_rectangles, colorbar_hydrologicalyears

os.chdir(pwd)

# For proper plotting on server
if socket.gethostname() == 'tik43x':
    mpl.use('Agg')

ALL_FIG = True
fig_weatherstation = False
fig_temperature_displacement = False
fig_dataavailability = True
#%% DEFINE PATH DATA
if os.getcwd() == '/home/perma/permasense_vault/scratch/essd_zenodo_datamgr/examples': 
    PATH_DATA = './../dh_data/'
    PATH_FIGURES = './figures_gnss/'
else:
    PATH_DATA = './../dh_data/'
    PATH_FIGURES = './figures_gnss/'
os.makedirs(PATH_FIGURES, exist_ok=True)    

year_list = list(range(2008, dt.datetime.today().year + 1))
color_list = mpl.cm.tab10(np.linspace(0, 1, len(year_list))) # OR itertools.cycle(["r", "b", "g"]) with import itertools
if len(year_list) <= 10: 
    color_list = mpl.cm.tab10(range(0, len(year_list))) # OR itertools.cycle(["r", "b", "g"]) with import itertools
elif len(year_list) > 10:
    color_list = mpl.cm.tab20(range(0, len(year_list))) # OR itertools.cycle(["r", "b", "g"]) with import itertools

years = mdates.YearLocator()   # every year
biyearly =mdates.YearLocator(2)
months = mdates.MonthLocator()  # every month
yearsFmt = mdates.DateFormatter('%Y')

xpos_ylabel_square = -0.14

plt.rcParams.update({'font.size': 12})

color1 = 'black' #color = 'deepskyblue'
color2 = 'C2'#'deepskyblue' #color = 'deepskyblue'


if fig_temperature_displacement | ALL_FIG:
    depo_adm = 'AD08'
    vsensor_adm = 'temperature_rock'
    PATH_DATA_ADM = './../adm_data/'
    df_adm = load_data(PATH_DATA_ADM + 'timeseries_derived_data_products/', depo_adm, vsensor_adm, year=year_list, file_type='csv')
    #df_adm  = df_adm.groupby(pd.Grouper(freq='M')).aggregate(np.mean)

    df_sto = pd.read_csv('STO_6000.csv', low_memory=False, parse_dates=True, index_col='time')
    df_mat = pd.read_csv('MAT_0205.csv', low_memory=False, parse_dates=True, index_col='time')

    depo1 = 'BH13'
    vsensor1 = 'gps_differential__rtklib__daily'
    vsensor2 = 'gps_inclinometer'
    df1 = load_data(PATH_DATA + 'gnss_derived_data_products/', depo1, vsensor1, year=year_list, file_type='csv')
    df1 = df1.resample('D').mean()
    df1d = df1.interpolate(method='linear')

    df1m  = df1d.groupby(pd.Grouper(freq='M')).diff()
    df1m  = df1m.groupby(pd.Grouper(freq='M')).aggregate(np.sum)

    df1a  = df1d.groupby(pd.Grouper(freq='Y')).diff()
    df1a  = df1a.groupby(pd.Grouper(freq='Y')).aggregate(np.sum)

    df1d['hydrological_year'] = (df1d.index + pd.DateOffset(months=3)).year
    df1ha  = df1d.groupby(pd.Grouper(key='hydrological_year')).diff()
    df1ha['hydrological_year'] = pd.to_datetime((df1ha.index + pd.DateOffset(months=3)).year, format='%Y') + pd.DateOffset(months=3) - pd.DateOffset(days=1)
    df1ha  = df1ha.groupby(pd.Grouper(key='hydrological_year')).aggregate(np.sum)

    df1m_diff = (df1m['e [m]'].pow(2) + df1m['n [m]'].pow(2) + df1m['h [m]'].pow(2)).pow(1./2)
    df1a_diff = (df1a['e [m]'].pow(2) + df1a['n [m]'].pow(2) + df1a['h [m]'].pow(2)).pow(1./2)
    df1ha_diff = (df1ha['e [m]'].pow(2) + df1ha['n [m]'].pow(2) + df1ha['h [m]'].pow(2)).pow(1./2)

    df1_i = load_data(PATH_DATA + 'timeseries_derived_data_products/', depo1, vsensor2, year=year_list, file_type='csv')
    df1_i = df1_i.resample('D').mean()
    df1d_i = df1_i.interpolate(method='linear')
    df1m_i  = df1d_i.groupby(pd.Grouper(freq='M')).diff()
    df1m_i  = df1m_i.groupby(pd.Grouper(freq='M')).aggregate(np.sum)
    df1m_i_diff = (df1m_i['inclinometer_north [°]'].pow(2) + df1m_i['inclinometer_north [°]'].pow(2)).pow(1./2)

    depo2 = 'LS05'
    df2 = load_data(PATH_DATA + 'gnss_derived_data_products/', depo2, vsensor1, year=year_list, file_type='csv')
    df2 = df2.resample('D').mean()
    df2d = df2.interpolate(method='linear')
    df2m  = df2d.groupby(pd.Grouper(freq='M')).diff()
    df2m  = df2m.groupby(pd.Grouper(freq='M')).aggregate(np.sum)

    df2d['hydrological_year'] = (df2d.index + pd.DateOffset(months=3)).year
    df2ha  = df2d.groupby(pd.Grouper(key='hydrological_year')).diff()
    df2ha['hydrological_year'] = pd.to_datetime((df2ha.index + pd.DateOffset(months=3)).year, format='%Y') + pd.DateOffset(months=3) - pd.DateOffset(days=1)
    df2ha  = df2ha.groupby(pd.Grouper(key='hydrological_year')).aggregate(np.sum)
    #print(df2ha)
    df2a  = df2d.groupby(pd.Grouper(freq='Y')).diff()
    df2a  = df2a.groupby(pd.Grouper(freq='Y')).aggregate(np.sum)
    df2m_diff = (df2m['e [m]'].pow(2) + df2m['n [m]'].pow(2) + df2m['h [m]'].pow(2)).pow(1./2)
    df2a_diff = (df2a['e [m]'].pow(2) + df2a['n [m]'].pow(2) + df2a['h [m]'].pow(2)).pow(1./2)
    df2ha_diff = (df2ha['e [m]'].pow(2) + df2ha['n [m]'].pow(2) + df2ha['h [m]'].pow(2)).pow(1./2)

    df2_i = load_data(PATH_DATA + 'timeseries_derived_data_products/', depo2, vsensor2, year=year_list, file_type='csv')
    df2_i = df2_i.resample('D').mean()
    df2d_i = df2_i.interpolate(method='linear')
    df2m_i  = df2d_i.groupby(pd.Grouper(freq='M')).diff()
    df2m_i  = df2m_i.groupby(pd.Grouper(freq='M')).aggregate(np.sum)
    df2m_i_diff = (df2m_i['inclinometer_north [°]'].pow(2) + df2m_i['inclinometer_west [°]'].pow(2)).pow(1./2)

    depo3 = 'GG01'
    df3 = load_data(PATH_DATA + 'gnss_derived_data_products/', depo3, vsensor1, year=year_list, file_type='csv')
    df3 = df3.resample('D').mean()
    df3d = df3.interpolate(method='linear')
    df3m  = df3d.groupby(pd.Grouper(freq='M')).diff()
    df3m  = df3m.groupby(pd.Grouper(freq='M')).aggregate(np.sum)

    df3d['hydrological_year'] = (df3d.index + pd.DateOffset(months=3)).year
    df3ha  = df3d.groupby(pd.Grouper(key='hydrological_year')).diff()
    df3ha['hydrological_year'] = pd.to_datetime((df3ha.index + pd.DateOffset(months=3)).year, format='%Y') + pd.DateOffset(months=3) - pd.DateOffset(days=1)
    df3ha  = df3ha.groupby(pd.Grouper(key='hydrological_year')).aggregate(np.sum)
    #print(df3ha)
    df3a  = df3d.groupby(pd.Grouper(freq='Y')).diff()
    df3a  = df3a.groupby(pd.Grouper(freq='Y')).aggregate(np.sum)
    df3m_diff = (df3m['e [m]'].pow(2) + df3m['n [m]'].pow(2) + df3m['h [m]'].pow(2)).pow(1./2)
    df3a_diff = (df3a['e [m]'].pow(2) + df3a['n [m]'].pow(2) + df3a['h [m]'].pow(2)).pow(1./2)
    df3ha_diff = (df3ha['e [m]'].pow(2) + df3ha['n [m]'].pow(2) + df3ha['h [m]'].pow(2)).pow(1./2)

    df3_i = load_data(PATH_DATA + 'timeseries_derived_data_products/', depo3, vsensor2, year=year_list, file_type='csv')
    df3_i = df3_i.resample('D').mean()
    df3d_i = df3_i.interpolate(method='linear')
    df3m_i  = df3_i.groupby(pd.Grouper(freq='M')).diff()
    df3m_i  = df3m_i.groupby(pd.Grouper(freq='M')).aggregate(np.sum)
    df3m_i_diff = (df3m_i['inclinometer_north [°]'].pow(2) + df3m_i['inclinometer_west [°]'].pow(2)).pow(1./2)

    depo4 = 'GG02'
    df4 = load_data(PATH_DATA + 'gnss_derived_data_products/', depo4, vsensor1, year=year_list, file_type='csv')
    df4 = df4.resample('D').mean()
    df4d = df4.interpolate(method='linear')
    df4m  = df4d.groupby(pd.Grouper(freq='M')).diff()
    df4m  = df4m.groupby(pd.Grouper(freq='M')).aggregate(np.sum)

    df4d['hydrological_year'] = (df4d.index + pd.DateOffset(months=3)).year
    df4ha  = df4d.groupby(pd.Grouper(key='hydrological_year')).diff()
    df4ha['hydrological_year'] = pd.to_datetime((df4ha.index + pd.DateOffset(months=3)).year, format='%Y') + pd.DateOffset(months=3) - pd.DateOffset(days=1)
    df4ha  = df4ha.groupby(pd.Grouper(key='hydrological_year')).aggregate(np.sum)
    #print(df4ha)
    df4a  = df4d.groupby(pd.Grouper(freq='Y')).diff()
    df4a  = df4a.groupby(pd.Grouper(freq='Y')).aggregate(np.sum)
    df4m_diff = (df4m['e [m]'].pow(2) + df4m['n [m]'].pow(2) + df4m['h [m]'].pow(2)).pow(1./2)
    df4a_diff = (df4a['e [m]'].pow(2) + df4a['n [m]'].pow(2) + df4a['h [m]'].pow(2)).pow(1./2)
    df4ha_diff = (df4ha['e [m]'].pow(2) + df4ha['n [m]'].pow(2) + df4ha['h [m]'].pow(2)).pow(1./2)

    df4_i = load_data(PATH_DATA + 'timeseries_derived_data_products/', depo4, vsensor2, year=year_list, file_type='csv')
    df4_i = df4_i.resample('D').mean()
    df4d_i = df4_i.interpolate(method='linear')
    df4m_i  = df4_i.groupby(pd.Grouper(freq='M')).diff()
    df4m_i  = df4m_i.groupby(pd.Grouper(freq='M')).aggregate(np.sum)
    df4m_i_diff = (df4m_i['inclinometer_north [°]'].pow(2) + df4m_i['inclinometer_west [°]'].pow(2)).pow(1./2)

    depo5 = 'COR1'
    df5 = load_data(PATH_DATA + 'gnss_derived_data_products/', depo5, vsensor1, year=year_list, file_type='csv')
    df5 = df5.resample('D').mean()
    df5d = df5.interpolate(method='linear')
    df5m  = df5d.groupby(pd.Grouper(freq='M')).diff()
    df5m  = df5m.groupby(pd.Grouper(freq='M')).aggregate(np.sum)

    df5d['hydrological_year'] = (df5d.index + pd.DateOffset(months=3)).year
    df5ha  = df5d.groupby(pd.Grouper(key='hydrological_year')).diff()
    df5ha['hydrological_year'] = pd.to_datetime((df5ha.index + pd.DateOffset(months=3)).year, format='%Y') + pd.DateOffset(months=3) - pd.DateOffset(days=1)
    df5ha  = df5ha.groupby(pd.Grouper(key='hydrological_year')).aggregate(np.sum)
    #print(df5ha)
    df5a  = df5d.groupby(pd.Grouper(freq='Y')).diff()
    df5a  = df5a.groupby(pd.Grouper(freq='Y')).aggregate(np.sum)
    df5m_diff = (df5m['e [m]'].pow(2) + df5m['n [m]'].pow(2) + df5m['h [m]'].pow(2)).pow(1./2)
    df5a_diff = (df5a['e [m]'].pow(2) + df5a['n [m]'].pow(2) + df5a['h [m]'].pow(2)).pow(1./2)
    df5ha_diff = (df5ha['e [m]'].pow(2) + df5ha['n [m]'].pow(2) + df5ha['h [m]'].pow(2)).pow(1./2)

    df5_i = load_data(PATH_DATA + 'timeseries_derived_data_products/', depo5, vsensor2, year=year_list, file_type='csv')
    df5_i = df5_i.resample('D').mean()
    df5d_i = df5_i.interpolate(method='linear')
    df5m_i  = df5_i.groupby(pd.Grouper(freq='M')).diff()
    df5m_i  = df5m_i.groupby(pd.Grouper(freq='M')).aggregate(np.sum)
    df5m_i_diff = (df5m_i['inclinometer_north [°]'].pow(2) + df5m_i['inclinometer_west [°]'].pow(2)).pow(1./2)

    depo6 = 'LS11'
    df6 = load_data(PATH_DATA + 'gnss_derived_data_products/', depo6, vsensor1, year=year_list, file_type='csv')
    df6 = df6.resample('D').mean()
    df6d = df6.interpolate(method='linear')
    df6m  = df6d.groupby(pd.Grouper(freq='M')).diff()
    df6m  = df6m.groupby(pd.Grouper(freq='M')).aggregate(np.sum)

    df6d['hydrological_year'] = (df6d.index + pd.DateOffset(months=3)).year
    df6ha  = df6d.groupby(pd.Grouper(key='hydrological_year')).diff()
    df6ha['hydrological_year'] = pd.to_datetime((df6ha.index + pd.DateOffset(months=3)).year, format='%Y') + pd.DateOffset(months=3) - pd.DateOffset(days=1)
    df6ha  = df6ha.groupby(pd.Grouper(key='hydrological_year')).aggregate(np.sum)
    #print(df6ha)
    df6a  = df6d.groupby(pd.Grouper(freq='Y')).diff()
    df6a  = df6a.groupby(pd.Grouper(freq='Y')).aggregate(np.sum)
    df6m_diff = (df6m['e [m]'].pow(2) + df6m['n [m]'].pow(2) + df6m['h [m]'].pow(2)).pow(1./6)
    df6a_diff = (df6a['e [m]'].pow(2) + df6a['n [m]'].pow(2) + df6a['h [m]'].pow(2)).pow(1./2)
    df6ha_diff = (df6ha['e [m]'].pow(2) + df6ha['n [m]'].pow(2) + df6ha['h [m]'].pow(2)).pow(1./2)

    df6_i = load_data(PATH_DATA + 'timeseries_derived_data_products/', depo6, vsensor2, year=year_list, file_type='csv')
    df6_i = df6_i.resample('D').mean()
    df6d_i = df6_i.interpolate(method='linear')
    df6m_i  = df6d_i.groupby(pd.Grouper(freq='M')).diff()
    df6m_i  = df6m_i.groupby(pd.Grouper(freq='M')).aggregate(np.sum)
    df6m_i_diff = (df6m_i['inclinometer_north [°]'].pow(2) + df6m_i['inclinometer_west [°]'].pow(2)).pow(1./2)

    fig, (ax1, ax2, ax3, ax4) = plt.subplots(4,1, figsize=(26/2.54, 34/2.54), facecolor='w', edgecolor='k')
    plt.subplots_adjust(left=0.09, right=0.92, bottom=0.08, top=0.99) # left=0.125, right=0.9, bottom=0.1, top=0.9, wspace=0.2, hspace=0.2

    #ax2 = ax1.twinx()
    #ax1.plot(df_mat['10'], color=color_list[0], label='Matterhorn @ -10m')
    ax1.plot(df_sto['11.3'],                    color=color_list[0], label='Stockhorn @ -11.3m')
    ax1.plot(df_adm['temperature_1000cm [°C]'], color=color_list[1], label='Aig. du Midi @ -10m')
    #ax1.plot(df_adm['temperature_900cm [°C]'], color=color_list[0], label='AD08')
    #ax1.plot(df_adm['temperature_700cm [°C]'], color=color_list[0], label='AD08')
    #t1, t2 = dataavailability_flags(df_adm['temperature_1000cm [°C]'])

    ax2.plot(df1ha_diff, drawstyle="steps-mid", alpha=0.8, label='BH13', color=color_list[0]) 
    ax2.plot(df3ha_diff, drawstyle="steps-mid", alpha=0.5, label='GG01', color=color_list[2]) 
    ax2.plot(df4ha_diff, drawstyle="steps-mid", alpha=0.8, label='GG02', color=color_list[2])
    ax2.plot(df5ha_diff, drawstyle="steps-mid", alpha=0.8, label='COR1', color=color_list[6])  
    ax2.plot(df2ha_diff, drawstyle="steps-mid", alpha=0.8, label='LS05', color=color_list[4]) 
    ax2.plot(df6ha_diff, drawstyle="steps-mid", alpha=0.5, label='LS11', color=color_list[4]) 

    ax3.plot(df1m_diff, drawstyle="steps-pre", alpha=0.8, label='BH13', color=color_list[0])
    ax3.plot(df3m_diff, drawstyle="steps-pre", alpha=0.5, label='GG01', color=color_list[2])
    ax3.plot(df4m_diff, drawstyle="steps-pre", alpha=0.8, label='GG02', color=color_list[2])
    ax3.plot(df5m_diff, drawstyle="steps-pre", alpha=0.8, label='COR1', color=color_list[6])
    ax3.plot(df2m_diff, drawstyle="steps-pre", alpha=0.8, label='LS05', color=color_list[4])
    ax3.plot(df6m_diff, drawstyle="steps-pre", alpha=0.5, label='LS11', color=color_list[4])

    # ax4.plot(df1m_i['inclinometer_north [°]'], drawstyle="steps-pre",  alpha=0.8, label='BH13 North')
    # ax4.plot(df1m_i['inclinometer_west [°]'], drawstyle="steps-pre", alpha=0.8, label='BH13 West')
    # ax4.plot(df2m_i['inclinometer_north [°]'], drawstyle="steps-pre",  alpha=0.8, label='LS05 North')
    # ax4.plot(df2m_i['inclinometer_west [°]'], drawstyle="steps-pre", alpha=0.8, label='LS05 West')
    # ax4.plot(df3m_i['inclinometer_north [°]'], drawstyle="steps-pre",  alpha=0.8, label='GG01 North')
    # ax4.plot(df3m_i['inclinometer_west [°]'], drawstyle="steps-pre", alpha=0.8, label='GG01 West')
    # ax4.plot(df5m_i['inclinometer_north [°]'], drawstyle="steps-pre",  alpha=0.8, label='COR1 North')
    # ax4.plot(df5m_i['inclinometer_west [°]'], drawstyle="steps-pre", alpha=0.8, label='COR1 West')
    ax4.plot(df1m_i_diff, drawstyle="steps", alpha=0.8, label='BH13', color=color_list[0])
    ax4.plot(df3m_i_diff, drawstyle="steps", alpha=0.5, label='GG01', color=color_list[2])
    ax4.plot(df4m_i_diff, drawstyle="steps", alpha=0.8, label='GG02', color=color_list[2])
    ax4.plot(df5m_i_diff, drawstyle="steps", alpha=0.8, label='COR1', color=color_list[6])
    ax4.plot(df2m_i_diff, drawstyle="steps", alpha=0.8, label='LS05', color=color_list[4])
    ax4.plot(df6m_i_diff, drawstyle="steps", alpha=0.5, label='LS11', color=color_list[4])

    ax1.legend(title="Borehole temperatures", loc="center left")
    ax2.legend(title="Annual 3D displacement", loc="upper left", ncol=2)
    ax3.legend(title="Monthly 3D displacement", loc="upper left", ncol=2)
    ax4.legend(title="Monthly inclination change", loc="upper left", ncol=2)


    #ax1.set_yticks(range(-30,20,10))
    #ax4.set_ylim([-1, 1])


    t1, t2 = dataavailability_flags(df3m['h [m]'])
    date_format = mdates.DateFormatter('%Y')

    ax1.set_xlim([t2[0], t1[-1]])
    ax1.xaxis.set_major_locator(biyearly)
    ax1.xaxis.set_minor_locator(years)
    ax1.xaxis.set_major_formatter(date_format)
    ax1.set_ylabel('Temperature [°C]')

    ax2.set_xlim([t2[0], t1[-1]])
    ax2.xaxis.set_major_locator(biyearly)
    ax2.xaxis.set_minor_locator(years)
    ax2.xaxis.set_major_formatter(date_format)
    ax2.set_ylabel('[m/a]')
    ax2.axhline(y=0, linestyle='dotted', linewidth=1, color='grey')

    ax3.set_xlim([t2[0], t1[-1]])
    ax3.xaxis.set_major_locator(biyearly)
    ax3.xaxis.set_minor_locator(years)
    ax3.xaxis.set_major_formatter(date_format)
    ax3.set_ylabel('[m/month]')
    ax3.axhline(y=0, linestyle='dotted', linewidth=1, color='grey')

    ax4.set_xlim([t2[0], t1[-1]])
    ax4.xaxis.set_major_locator(biyearly)
    ax4.xaxis.set_minor_locator(years)
    ax4.xaxis.set_major_formatter(date_format)
    ax4.set_ylabel('Inclination [°/month]')
    ax4.set_yscale('log')
    ax4.set_ylim([10e-4, 10e1])
    ax4.yaxis.grid(True, which="major", linestyle='dotted')
    #ax4.axhline(y=0, linestyle='dotted', color='grey')

    fname = 'fig_temperature_displacement.png'
    plt.savefig(PATH_FIGURES + fname, format='png', dpi=300) #bbox_inches="tight", pad_inches=0,


# Air temperature and radiation
if fig_weatherstation | ALL_FIG:

    color_list = mpl.cm.tab10(np.linspace(0, 1, 6))

    depo1 = 'DH13'
    vsensor1 = 'vaisalawxt520windpth'
    df1 = load_data(PATH_DATA + 'timeseries_derived_data_products/', depo1, vsensor1, year=year_list, file_type='csv')
    df1 = df1.groupby(pd.Grouper(freq='10080Min')).aggregate(np.mean)
    
    depo2 = 'DH42'
    vsensor2 = 'vaisalawxt520windpth'
    df2 = load_data(PATH_DATA + 'timeseries_derived_data_products/', depo2, vsensor2, year=year_list, file_type='csv')
    df2 = df2.groupby(pd.Grouper(freq='10080Min')).aggregate(np.mean)

    depo3 = 'DH68'
    vsensor3 = 'vaisalawxt520windpth'
    df3 = load_data(PATH_DATA + 'timeseries_derived_data_products/', depo3, vsensor3, year=year_list, file_type='csv')
    df3 = df3.groupby(pd.Grouper(freq='10080Min')).aggregate(np.mean)

    depo4 = 'DH69'
    vsensor4 = 'vaisalawxt520windpth'
    df4 = load_data(PATH_DATA + 'timeseries_derived_data_products/', depo4, vsensor4, year=year_list, file_type='csv')
    df4 = df4.groupby(pd.Grouper(freq='10080Min')).aggregate(np.mean)

    depo5 = 'MH25'
    vsensor5 = 'vaisalawxt520windpth'
    df5 = load_data(PATH_DATA + 'timeseries_derived_data_products/', depo5, vsensor5, year=year_list, file_type='csv')
    df5 = df5.groupby(pd.Grouper(freq='10080Min')).aggregate(np.mean)

    depo6 = 'MH51'
    vsensor6 = 'vaisalawxt520windpth'
    df6 = load_data(PATH_DATA + 'timeseries_derived_data_products/', depo6, vsensor6, year=year_list, file_type='csv')
    df6 = df6.groupby(pd.Grouper(freq='10080Min')).aggregate(np.mean)

    depo7 = 'MH15'
    vsensor7 = 'radiometer__conv'
    df7 = load_data(PATH_DATA + 'timeseries_derived_data_products/', depo7, vsensor7, year=year_list, file_type='csv')
    df7 = df7.groupby(pd.Grouper(freq='1440Min')).aggregate(np.mean)
    
    depo8 = 'DH73'
    vsensor8 = 'radiometer__conv'
    df8 = load_data(PATH_DATA + 'timeseries_derived_data_products/', depo8, vsensor8, year=year_list, file_type='csv')
    df8 = df8.groupby(pd.Grouper(freq='1440Min')).aggregate(np.mean)

    depo = '{:s}_{:s}'.format(depo1,depo2,depo3,depo4,depo5,depo6,depo7,depo8)
    vsensor = '{:s}_{:s}'.format(vsensor1,vsensor6)
    df = pd.concat([df1, df2, df3, df4, df5, df6, df7, df8], axis=1, join='inner')
    #df['hydrological_year'] = (df.index + pd.DateOffset(months=3)).year
    
    
    fig, ax1 = plt.subplots(1,1, figsize=(26/2.54, 10/2.54), facecolor='w', edgecolor='k')
    plt.subplots_adjust(left=0.07, right=0.92, bottom=0.08, top=0.99) # left=0.125, right=0.9, bottom=0.1, top=0.9, wspace=0.2, hspace=0.2
    #fig, ax1 = plt.subplots(1,1, figsize=(12/2.54, 8/2.54), facecolor='w', edgecolor='k')
    #plt.subplots_adjust(left=0.15, right=0.85, bottom=0.08, top=0.99) # left=0.125, right=0.9, bottom=0.1, top=0.9, wspace=0.2, hspace=0.2
    
    ax1.plot(df1['temp_air [°C]'], color=color_list[0], label='DH13')
    t1, t2 = dataavailability_flags(df5['temp_air [°C]'])
    # nodata_rectangles(ax1, t1, t2, facecolor=color_list[0], alpha=0.2)
      
    ax1.plot(df2['temp_air [°C]'], color=color_list[1], label='DH42')
    # t1, t2 = dataavailability_flags(df2['temp_air [°C]'])
    # nodata_rectangles(ax1, t1, t2, facecolor=color_list[1], alpha=0.2)

    ax1.plot(df3['temp_air [°C]'], color=color_list[2], label='DH68')
    # t1, t2 = dataavailability_flags(df3['temp_air [°C]'])
    # nodata_rectangles(ax1, t1, t2, facecolor=color_list[2], alpha=0.2)

    ax1.plot(df4['temp_air [°C]'], color=color_list[3], label='DH69')
    # t1, t2 = dataavailability_flags(df4['temp_air [°C]'])
    # nodata_rectangles(ax1, t1, t2, facecolor=color_list[3], alpha=0.2)

    ax1.plot(df5['temp_air [°C]'], color=color_list[4], label='MH25')
    # t1, t2 = dataavailability_flags(df5['temp_air [°C]'])
    # nodata_rectangles(ax1, t1, t2, facecolor=color_list[4], alpha=0.2)

    ax1.plot(df6['temp_air [°C]'], color=color_list[5], label='MH51')
    # t1, t2 = dataavailability_flags(df5['temp_air [°C]'])
    # nodata_rectangles(ax1, t1, t2, facecolor=color_list[4], alpha=0.2)


    ax2 = ax1.twinx()
    ax2.plot(df7['net_radiation [Wm^-2]'], color=color2, alpha=0.3, label='MH15') #, linewidth=1 #ax3.set_ylim([44,50])
    ax2.plot(df8['net_radiation [Wm^-2]'], color=color1, alpha=0.5, label='DH73') #, linewidth=1 #ax3.set_ylim([44,50])
    
    ax1.legend(loc="lower left")
    ax2.legend(loc="lower center")
    # option one legend
    # lines1, labels1 = ax1.get_legend_handles_labels()
    # lines2, labels2 = ax2.get_legend_handles_labels()
    # ax2.legend(lines1 + lines2, labels1 + labels2, loc='lower center')

    ax1.set_ylabel('Air temperature [°C]')
    ax1.set_ylim([-45, 20])
    ax1.set_yticks(range(-30,20,10))
    ax1.axhline(y=0, linestyle='dotted', linewidth=1, color='grey')

    ax1.xaxis.set_major_locator(biyearly)
    ax1.xaxis.set_minor_locator(years)
    ax1.set_xlim([t2[0], t1[-1]])
    date_format = mdates.DateFormatter('%Y')
    ax1.xaxis.set_major_formatter(date_format)
    
    ax2.set_ylabel(r'Total Net Radiation [Wm$^{-2}$]', color=color2)
    ax2.set_ylim([-100, 900])
    ax2.set_yticks(range(-100,400,100))
    #ax2.axhline(y=0, linestyle='dotted', linewidth=1, color='grey')
    for tl in ax2.get_yticklabels():
        tl.set_color(color2)
    ax2.tick_params(axis='y', colors=color2)
    ax2.spines['right'].set_color(color2)
    
    fname = 'fig_{:s}.png'.format(vsensor)
    plt.savefig(PATH_FIGURES + fname, format='png', dpi=300) #bbox_inches="tight", pad_inches=0,


    
    
#%%
if fig_dataavailability | ALL_FIG:

    DEPO_VS1 = {
            'RD01': {'gps_differential__batch__daily','gps_differential__rtklib__daily'},                    #                    OK
            'DI55': {'gps_differential__batch__daily','gps_differential__rtklib__daily'},                    #                    OK
            'RA01': {'gps_differential__batch__daily','gps_differential__rtklib__daily','gps_inclinometer'}, #000deg,             OK
            'DI57': {'gps_differential__batch__daily','gps_differential__rtklib__daily'},                    #                    OK
            'RA02': {'gps_differential__batch__daily','gps_differential__rtklib__daily','gps_inclinometer'}, #000deg,             OK
            'BH03': {'gps_differential__batch__daily','gps_differential__rtklib__daily'},                    #                    OK
            'DI02': {'gps_differential__batch__daily','gps_differential__rtklib__daily','gps_inclinometer'}, #225/131/281/246deg, OK
            'DI07': {'gps_differential__batch__daily','gps_differential__rtklib__daily','gps_inclinometer'}, #105/277/321/334deg, OK
            'LS01': {'gps_differential__batch__daily','gps_differential__rtklib__daily','gps_inclinometer'}, #110deg,             OK
            'LS04': {'gps_differential__batch__daily','gps_differential__rtklib__daily','gps_inclinometer'}, #225deg,             OK
            'BH07': {'gps_differential__batch__daily','gps_differential__rtklib__daily','gps_inclinometer'}, #240deg,             OK
            'BH09': {'gps_differential__batch__daily','gps_differential__rtklib__daily','gps_inclinometer'}, #130deg,             OK
            'ST02': {'gps_differential__batch__daily','gps_differential__rtklib__daily','gps_inclinometer'}, #004deg,             OK
            'ST05': {'gps_differential__batch__daily','gps_differential__rtklib__daily','gps_inclinometer'}, #124deg,             OK 
            'GU02': {'gps_differential__batch__daily','gps_differential__rtklib__daily','gps_inclinometer'}, #335deg,             OK
            'GU03': {'gps_differential__batch__daily','gps_differential__rtklib__daily','gps_inclinometer'}, #010deg,             OK
            'RG01': {'gps_differential__batch__daily','gps_differential__rtklib__daily'},                    #                    OK
            'GG52': {'gps_differential__batch__daily','gps_differential__rtklib__daily'},                    #                    OK
            }

    DEPO_VS2 = {
            'GG01': {'gps_differential__batch__daily','gps_differential__rtklib__daily','gps_inclinometer'}, #325deg,             OK
            'GG02': {'gps_differential__batch__daily','gps_differential__rtklib__daily','gps_inclinometer'}, #205/041deg          OK
            'BH10': {'gps_differential__batch__daily','gps_differential__rtklib__daily','gps_inclinometer'}, #280/270/294/312deg  OK
            'RL01': {'gps_differential__batch__daily','gps_differential__rtklib__daily','gps_inclinometer'}, #309deg              OK
            'GU04': {'gps_differential__batch__daily','gps_differential__rtklib__daily','gps_inclinometer'}, #014deg,             OK
            'BH12': {'gps_differential__batch__daily','gps_differential__rtklib__daily','gps_inclinometer'}, #140deg,             OK
            'BH13': {'gps_differential__batch__daily','gps_differential__rtklib__daily','gps_inclinometer'}, #090/000deg,         OK
            'LS05': {'gps_differential__batch__daily','gps_differential__rtklib__daily','gps_inclinometer'}, #318/330deg,         OK
            'GG66': {'gps_differential__batch__daily','gps_differential__rtklib__daily'}, #,                                      OK
            'GG67': {'gps_differential__batch__daily','gps_differential__rtklib__daily'}, #,                                      OK
            'RA03': {'gps_differential__batch__daily','gps_differential__rtklib__daily','gps_inclinometer'}, #000deg,             OK
            'RAND': {'gps_differential__batch__daily','gps_differential__rtklib__daily'},                    #,                   OK
            'WYS1': {'gps_differential__batch__daily','gps_differential__rtklib__daily','gps_inclinometer'}, #170deg,             OK
            'LS11': {'gps_differential__batch__daily','gps_differential__rtklib__daily','gps_inclinometer'}, #262deg,             OK
            'LS12': {'gps_differential__batch__daily','gps_differential__rtklib__daily','gps_inclinometer'}, #006deg,             OK
            'DI03': {'gps_differential__batch__daily','gps_differential__rtklib__daily','gps_inclinometer'}, #000deg,             OK
            'DI04': {'gps_differential__batch__daily','gps_differential__rtklib__daily','gps_inclinometer'}, #000deg,             OK
            'LS06': {'gps_differential__rtklib__daily','gps_inclinometer'}, #000deg,             OK
            }

    DEPO_VS3 = {          
            'DH13': {'vaisalawxt520prec', 'vaisalawxt520windpth'},                                           #
            'DH42': {'vaisalawxt520prec', 'vaisalawxt520windpth'},                                           #
            'DH68': {'vaisalawxt520prec', 'vaisalawxt520windpth'},                                           #
            'DH69': {'vaisalawxt520prec', 'vaisalawxt520windpth'},                                           #
            'DH73': {'radiometer__conv'},                                                                    #

            'DIS1': {'gps_differential__batch__daily','gps_differential__rtklib__daily','gps_inclinometer'}, #,                   OK
            'DIS2': {'gps_differential__batch__daily','gps_differential__rtklib__daily','gps_inclinometer'}, #,                   OK
            'RIT1': {'gps_differential__batch__daily','gps_differential__rtklib__daily','gps_inclinometer'}, #,                   OK
            'GRU1': {'gps_differential__batch__daily','gps_differential__rtklib__daily','gps_inclinometer'}, #,                   OK
            'JAE1': {'gps_differential__batch__daily','gps_differential__rtklib__daily','gps_inclinometer'}, #,                   OK
            'SCH1': {'gps_differential__batch__daily','gps_differential__rtklib__daily','gps_inclinometer'}, #,                   OK
            'MUA1': {'gps_differential__batch__daily','gps_differential__rtklib__daily','gps_inclinometer'}, #,                   OK
            'LAR1': {'gps_differential__batch__daily','gps_differential__rtklib__daily','gps_inclinometer'}, #,                   OK
            'LAR2': {'gps_differential__batch__daily','gps_differential__rtklib__daily','gps_inclinometer'}, #,                   OK
            'COR1': {'gps_differential__batch__daily','gps_differential__rtklib__daily','gps_inclinometer'}, #,                   OK

            'MH15': {'radiometer__conv'},                                                                            #ok
            'MH25': {'vaisalawxt520windpth','vaisalawxt520prec'},                  #ok
    
            'MH33': {'gps_differential__batch__daily', 'gps_differential__rtklib__daily', 'gps_inclinometer'},        #ok
            'MH34': {'gps_differential__batch__daily', 'gps_differential__rtklib__daily', 'gps_inclinometer'},        #ok
            'MH35': {'gps_differential__batch__daily', 'gps_differential__rtklib__daily', 'gps_inclinometer'},        #ok
            'MH40': {'gps_differential__batch__daily', 'gps_differential__rtklib__daily'},                            #ok
            'MH42': {'gps_differential__batch__daily', 'gps_differential__rtklib__daily'},                            #ok
            'MH43': {'gps_differential__rtklib__daily'},
            }
    
    DEPO_VS = DEPO_VS1
    #DEPO_VS = sorted(DEPO_VS1.items(), key=lambda x: x[0])

    n=1
    while n < 4:
        if n == 2:
            DEPO_VS = DEPO_VS2
            #DEPO_VS = sorted(DEPO_VS2.items(), key=lambda x: x[0])
        elif n == 3:
            DEPO_VS = DEPO_VS3
            #DEPO_VS = sorted(DEPO_VS2.items(), key=lambda x: x[0])

        no_subplots = 0
        for depo in DEPO_VS:
            for vsensor in list(DEPO_VS[depo]):
                no_subplots += 1
    
        fig, ax = plt.subplots(no_subplots,1, figsize=(25/2.54, 28/2.54), facecolor='w', edgecolor='k', sharex=True, sharey=True)
        plt.subplots_adjust(left=0.26, right=0.97, bottom=0.03, top=0.99, hspace=0) # left=0.125, right=0.9, bottom=0.1, top=0.9, wspace=0.2, hspace=0.2
            
        xpos_ylabel = -0.36

        #ax[0].set_xlim([dt.datetime(2008,9,1), dt.datetime(dt.datetime.today().year,1,1)])
        ax[0].set_xlim([dt.datetime(2010,10,1), dt.datetime(dt.datetime.today().year+1,1,1)])
        ax[0].set_yticks([])
            
        i=0
        
        for depo in DEPO_VS:
            print(depo)
            # print(list(DEPO_VS[depo]))

            # Loop through values for a given key of dictionary DEPO_VS
            for vsensor in list(DEPO_VS[depo]):
                # print(vsensor)
                df = pd.DataFrame()
                if df.empty:
                    try:
                        df = load_data(PATH_DATA + 'timeseries_derived_data_products/', depo, vsensor, year=year_list, file_type='csv')
                    except:
                        pass
                if df.empty:
                    try:
                        df = load_data(PATH_DATA + 'gnss_derived_data_products/', depo, vsensor, year=year_list, file_type='csv')
                    except:
                        pass

                ax[i].set_facecolor('darkgreen')
                
                try:
                    t1, t2 = dataavailability_flags(df['position []'], daily=True)
                except:
                    t1 = [pd.DataFrame([1], index=[pd.datetime(1970,1,1,1)]).index[0]]
                    t2 = [pd.DataFrame([1], index=[pd.datetime(2050,1,1,1)]).index[0]]
                    pass
                    
                nodata_rectangles(ax[i], t1, t2, facecolor='white', alpha=1)
                
                if vsensor.startswith('gps_differential'):
                    ax[i].set_ylabel('{:s} {:s}__{:s}'.format(depo, vsensor.split('__')[0], vsensor.split('__')[1]), rotation=0, ha='left')
                else:
                    ax[i].set_ylabel('{:s} {:s}'.format(depo, vsensor.split('__')[0]), rotation=0, ha='left')
                
                ax[i].yaxis.set_label_coords(xpos_ylabel, 0.1)
                ax[i].grid()
                i += 1
                
            
        print(i)
        fname = 'fig_data_availability'+ str(n) +'.png'
        plt.savefig(PATH_FIGURES + fname, format='png', dpi=300) #bbox_inches="tight", pad_inches=0,


        no_subplots = 0

        for depo in DEPO_VS:
            for vsensor in list(DEPO_VS[depo]):
                if not vsensor.startswith('gps_differential__batch'):
                    no_subplots += 1

        fig, ax = plt.subplots(no_subplots,1, figsize=(25/2.54, 16/2.54), facecolor='w', edgecolor='k', sharex=True, sharey=True)
        plt.subplots_adjust(left=0.26, right=0.97, bottom=0.06, top=0.99, hspace=0) # left=0.125, right=0.9, bottom=0.1, top=0.9, wspace=0.2, hspace=0.2

        ax[0].set_xlim([dt.datetime(2010,10,1), dt.datetime(dt.datetime.today().year+1,1,1)])
        ax[0].set_yticks([])
            
        i=0
        
        for depo in DEPO_VS:
            print(depo)
            # print(list(DEPO_VS[depo]))

            # Loop through values for a given key of dictionary DEPO_VS
            for vsensor in sorted(list(DEPO_VS[depo])):
                print(vsensor)
                if not vsensor.startswith('gps_differential__batch'):
                    df = pd.DataFrame()
                    if df.empty:
                        try:
                            df = load_data(PATH_DATA + 'timeseries_data_raw/', depo, vsensor, year=year_list, file_type='csv')
                        except:
                            pass
                    if df.empty:
                        try:
                            df = load_data(PATH_DATA + 'gnss_data_raw/', depo, vsensor, year=year_list, file_type='csv')
                        except:
                            pass

                    ax[i].set_facecolor('darkgreen')
                    
                    #print(vsensor)
                    if vsensor.startswith('gps_differential__rtklib'):
                        max_date = max(df.index)
                        min_date = min(df.index)

                        df_gnss = pd.DataFrame()
                        file_dates = []

                        while min_date <= max_date:
                            min_year = min_date.strftime('%y')
                            min_doy = min_date.strftime('%j')

                            gnss_filename = PATH_DATA + 'gnss_data_raw/' + depo + '/' + depo + min_doy + '0.' + min_year + 'O'
                            #print(gnss_filename)

                            if os.path.isfile(gnss_filename):
                                #print ("File exist")
                                file_dates.append(pd.to_datetime(min_date))
                            #else:
                                #print ("File does not exist")

                            #print(pd.to_datetime(min_date))

                            min_date = min_date + dt.timedelta(days=1)
                            #print(min_date)
                        
                        df_gnss['time'] = file_dates
                        df_gnss['position []'] = file_dates
                        df_gnss = df_gnss.set_index('time')
                        try:
                            t1, t2 = dataavailability_flags(df_gnss['position []'], daily=True)
                        except:
                            t1 = [pd.DataFrame([1], index=[pd.datetime(1970,1,1,1)]).index[0]]
                            t2 = [pd.DataFrame([1], index=[pd.datetime(2050,1,1,1)]).index[0]]
                            pass
                    elif vsensor.startswith('timeseries'):
                        try:
                            t1, t2 = dataavailability_flags(df['position []'], daily=True)
                        except:
                            t1 = [pd.DataFrame([1], index=[pd.datetime(1970,1,1,1)]).index[0]]
                            t2 = [pd.DataFrame([1], index=[pd.datetime(2050,1,1,1)]).index[0]]
                            pass
                    else:
                        pass
                        
                    try:
                            nodata_rectangles(ax[i], t1, t2, facecolor='white', alpha=1)
                    except:
                        pass

                    if vsensor.startswith('gps_differential'):
                        ax[i].set_ylabel('{:s} gps_raw'.format(depo), rotation=0, ha='left')
                    else:
                        ax[i].set_ylabel('{:s} {:s}'.format(depo, vsensor.split('__')[0]), rotation=0, ha='left')
                    
                    ax[i].yaxis.set_label_coords(xpos_ylabel, 0.1)
                    ax[i].grid()
                    i += 1

        print(i)
        fname = 'fig_raw_availability'+ str(n) +'.png'
        plt.savefig(PATH_FIGURES + fname, format='png', dpi=300)

        n += 1

